"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const helper_1 = require("./helper");
const error = new Error(`AWS Error`);
const createApiKey = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const createUsagePlan = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const createUsagePlanKey = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const deleteApiKey = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const deleteUsagePlan = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const deleteUsagePlanKey = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const getApiKey = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
jest.mock('@aws-sdk/client-api-gateway', () => {
    return {
        APIGateway: jest.fn().mockImplementation(() => {
            return {
                createApiKey,
                createUsagePlan,
                createUsagePlanKey,
                deleteApiKey,
                deleteUsagePlan,
                deleteUsagePlanKey,
                getApiKey,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const apiGatewayHelperMock = new helper_1.APIGatewayHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.CreateApiKeyAsync.name}`, () => {
    test(TestValues.InvalidTest, () => {
        const actual = apiGatewayHelperMock.CreateApiKeyAsync(TestValues.Name, TestValues.Description, TestValues.StringValue);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.CreateUsagePlanAsync.name}`, () => {
    test(TestValues.InvalidTest, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanAsync(TestValues.Name, TestValues.Description, TestValues.ApiStageArray);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.CreateUsagePlanKeyAsync.name}`, () => {
    test(TestValues.InvalidTest, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanKeyAsync(TestValues.Name, TestValues.Description, TestValues.UsagePlanId);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.DeleteApiKeyAsync.name}`, () => {
    test(TestValues.InvalidTest, () => {
        const actual = apiGatewayHelperMock.DeleteApiKeyAsync(TestValues.Key);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.DeleteUsagePlanAsync.name}`, () => {
    test(TestValues.InvalidTest, () => {
        const actual = apiGatewayHelperMock.DeleteUsagePlanAsync(TestValues.UsagePlanId);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.DeleteUsagePlanKeyAsync.name}`, () => {
    test(TestValues.InvalidTest, () => {
        const actual = apiGatewayHelperMock.DeleteUsagePlanKeyAsync(TestValues.Key, TestValues.UsagePlanId);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.GetApiKeyAsync.name}`, () => {
    test(TestValues.InvalidTest, () => {
        const actual = apiGatewayHelperMock.GetApiKeyAsync(TestValues.Key);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
//# sourceMappingURL=helper-rejects.spec.js.map