"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const helper_1 = require("./helper");
const apiKeyResponse = {};
const deleteApiKeyResponse = {};
const deleteUsagePlanResponse = {};
const deleteUsagePlanKeyResponse = {};
const usagePlanResponse = {};
const usagePlanKeyResponse = {};
const createApiKey = jest.fn().mockImplementation(() => {
    return Promise.resolve(apiKeyResponse);
});
const createUsagePlan = jest.fn().mockImplementation(() => {
    return Promise.resolve(usagePlanResponse);
});
const createUsagePlanKey = jest.fn().mockImplementation(() => {
    return Promise.resolve(usagePlanKeyResponse);
});
const deleteApiKey = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteApiKeyResponse);
});
const deleteUsagePlan = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteUsagePlanResponse);
});
const deleteUsagePlanKey = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteUsagePlanKeyResponse);
});
const getApiKey = jest.fn().mockImplementation(() => {
    return Promise.resolve(apiKeyResponse);
});
jest.mock('@aws-sdk/client-api-gateway', () => {
    return {
        APIGateway: jest.fn().mockImplementation(() => {
            return {
                createApiKey,
                createUsagePlan,
                createUsagePlanKey,
                deleteApiKey,
                deleteUsagePlan,
                deleteUsagePlanKey,
                getApiKey,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const apiGatewayHelperMock = new helper_1.APIGatewayHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.CreateApiKeyAsync.name}`, () => {
    const action = `${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.CreateApiKeyAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} name`, () => {
        const actual = apiGatewayHelperMock.CreateApiKeyAsync(TestValues.EmptyString, TestValues.Description);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} name`);
    });
    test(`${TestValues.ThrowsOnEmpty} description`, () => {
        const actual = apiGatewayHelperMock.CreateApiKeyAsync(TestValues.Name, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} description`);
    });
    test(TestValues.ValidTest, () => {
        const actual = apiGatewayHelperMock.CreateApiKeyAsync(TestValues.Name, TestValues.Description, TestValues.StringValue);
        return expect(actual).resolves.toEqual(apiKeyResponse);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.CreateUsagePlanAsync.name}`, () => {
    const action = `${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.CreateUsagePlanAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} name`, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanAsync(TestValues.EmptyString, TestValues.Description, TestValues.ApiStageArray);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} name`);
    });
    test(`${TestValues.ThrowsOnEmpty} description`, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanAsync(TestValues.Name, TestValues.EmptyString, TestValues.ApiStageArray);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} description`);
    });
    test(`${TestValues.ThrowsOnEmpty} apiStages`, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanAsync(TestValues.Name, TestValues.Description, TestValues.EmptyArray);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} at least one apiStage`);
    });
    test(TestValues.ValidTest, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanAsync(TestValues.Name, TestValues.Description, TestValues.ApiStageArray);
        return expect(actual).resolves.toEqual(usagePlanResponse);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.CreateUsagePlanKeyAsync.name}`, () => {
    const action = `${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.CreateUsagePlanKeyAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} keyId`, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanKeyAsync(TestValues.EmptyString, TestValues.Key, TestValues.UsagePlanId);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} keyId`);
    });
    test(`${TestValues.ThrowsOnEmpty} keyType`, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanKeyAsync(TestValues.Key, TestValues.EmptyString, TestValues.UsagePlanId);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} keyType`);
    });
    test(`${TestValues.ThrowsOnEmpty} usagePlanId`, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanKeyAsync(TestValues.Name, TestValues.Description, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} usagePlanId`);
    });
    test(TestValues.ValidTest, () => {
        const actual = apiGatewayHelperMock.CreateUsagePlanKeyAsync(TestValues.Name, TestValues.Description, TestValues.UsagePlanId);
        return expect(actual).resolves.toEqual(usagePlanKeyResponse);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.DeleteApiKeyAsync.name}`, () => {
    const action = `${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.DeleteApiKeyAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} apiKey`, () => {
        const actual = apiGatewayHelperMock.DeleteApiKeyAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} apiKey`);
    });
    test(TestValues.ValidTest, () => {
        const actual = apiGatewayHelperMock.DeleteApiKeyAsync(TestValues.Key);
        return expect(actual).resolves.toEqual(deleteApiKeyResponse);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.DeleteUsagePlanAsync.name}`, () => {
    const action = `${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.DeleteUsagePlanAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} usagePlanId`, () => {
        const actual = apiGatewayHelperMock.DeleteUsagePlanAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} usagePlanId`);
    });
    test(TestValues.ValidTest, () => {
        const actual = apiGatewayHelperMock.DeleteUsagePlanAsync(TestValues.UsagePlanId);
        return expect(actual).resolves.toEqual(deleteUsagePlanResponse);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.DeleteUsagePlanKeyAsync.name}`, () => {
    const action = `${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.DeleteUsagePlanKeyAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} keyId`, () => {
        const actual = apiGatewayHelperMock.DeleteUsagePlanKeyAsync(TestValues.EmptyString, TestValues.UsagePlanId);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} keyId`);
    });
    test(`${TestValues.ThrowsOnEmpty} usagePlanId`, () => {
        const actual = apiGatewayHelperMock.DeleteUsagePlanKeyAsync(TestValues.Key, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} usagePlanId`);
    });
    test(TestValues.ValidTest, () => {
        const actual = apiGatewayHelperMock.DeleteUsagePlanKeyAsync(TestValues.Key, TestValues.UsagePlanId);
        return expect(actual).resolves.toEqual(deleteUsagePlanKeyResponse);
    });
});
describe(`${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.GetApiKeyAsync.name}`, () => {
    const action = `${helper_1.APIGatewayHelper.name}.${apiGatewayHelperMock.GetApiKeyAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} apiKey`, () => {
        const actual = apiGatewayHelperMock.GetApiKeyAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} apiKey`);
    });
    test(TestValues.ValidTest, () => {
        const actual = apiGatewayHelperMock.GetApiKeyAsync(TestValues.Key);
        return expect(actual).resolves.toEqual(apiKeyResponse);
    });
});
//# sourceMappingURL=helper-resolves.spec.js.map